@@ -247,6 +247,7 @@ static gchar *contributors[] = {
 	/* Name in Japanese is: U7b39 U5c71 U548c U5b8f */
 	N_("Kazuhiro Sasayama"),
 	"Carsten Schaar",
+	"Christian Schaller",
 	"Franck Schneider",
 	"Ingo Schneider",
 	"Bernd Schroeder",
@@ -270,6 +271,7 @@ static gchar *contributors[] = {
 	N_("The Squeaky Rubber Gnome"),
 	"Maciej Stachowiak",
 	"Stalyn",
+	"Jakub Steiner",
 	"Ben Stern",
 	"Micah Stetson",
 	"Nathan Carl Summers",
